package
Version:
v0.0.0-...-927a21c
Opens a new window with list of versions in this module.
Published: May 12, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CloseMsg struct {
Skipped bool
}
const (
StepWelcome Step = iota
StepNavigation
StepCreation
StepCompletion
StepFilter
StepDashboard
StepAI
StepRecurring
StepAdvanced
StepFocus
StepUndoRedo
StepFinish
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.